<?php

namespace Drp\SimpleCms\Contracts;

/**
 * Class ContentFactory
 * @package Drp\SimpleCms
 */
interface ContentFactory
{
    /**
     * Return the latest Content using the type and ID.
     * First get the relevant Model using the type
     * and then get the latest using the ID.
     *
     * @param string $contentType
     * @param integer $contentId
     * @return \Drp\SimpleCms\Content
     * @throws \Illuminate\Database\Eloquent\ModelNotFoundException If a matching content was not found.
     */
    public function latestVersionByTypeAndContentId($contentType, $contentId);

    /**
     * Return the Content using the model id and the type.
     *
     * @param string $contentType
     * @param integer $versionId
     * @return \Drp\SimpleCms\Content
     */
    public static function byTypeAndVersionId($contentType, $versionId);

    /**
     * Return an instance of the content class based on the given content name.
     *
     * @param string $contentType The type of content object to return
     * @return \Drp\SimpleCms\Content
     */
    public static function makeContentClass($contentType);

    /**
     * Return the studies label based on type.
     *
     * @param string $contentType
     * @param boolean $plural
     * @param boolean $lowerCase
     * @return string
     */
    public static function contentLabel($contentType, $plural = null, $lowerCase = null);
}
